==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/ipayment_elv.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ipayment_elv.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_CFG_AUTH' => 'auth',
	'GM_CFG_NORMAL' => 'normal',
	'GM_CFG_PREAUTH' => 'preauth',
	'GM_CFG_SILENT' => 'silent',
	'MODULE_PAYMENT_IPAYMENT_ELV_ACCOUNT_ID_DESC' => 'Ihre Merchant ID',
	'MODULE_PAYMENT_IPAYMENT_ELV_ACCOUNT_ID_TITLE' => 'Merchant ID',
	'MODULE_PAYMENT_IPAYMENT_ELV_ADMINACTION_PASSWORD_DESC' => 'Ihr Adminaktionspasswort',
	'MODULE_PAYMENT_IPAYMENT_ELV_ADMINACTION_PASSWORD_TITLE' => 'Adminaktionspasswort',
	'MODULE_PAYMENT_IPAYMENT_ELV_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_IPAYMENT_ELV_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_IPAYMENT_ELV_APPLICATION_ID_DESC' => 'Ihre Merchant License',
	'MODULE_PAYMENT_IPAYMENT_ELV_APPLICATION_ID_TITLE' => 'Merchant License',
	'MODULE_PAYMENT_IPAYMENT_ELV_APPLICATION_PASSWORD_DESC' => 'Ihr Anwendungspasswort',
	'MODULE_PAYMENT_IPAYMENT_ELV_APPLICATION_PASSWORD_TITLE' => 'Anwendungspasswort',
	'MODULE_PAYMENT_IPAYMENT_ELV_AUTH_MODE_DESC' => 'Modus "auth": sofortige Zahlung, Modus "preauth": Verzögerte Zahlungsabwicklung',
	'MODULE_PAYMENT_IPAYMENT_ELV_AUTH_MODE_TITLE' => 'Transaktionsmodus',
	'MODULE_PAYMENT_IPAYMENT_ELV_ERRORORDER_STATUS_ID_DESC' => 'Bestellung im Fehlerfall auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_ELV_ERRORORDER_STATUS_ID_TITLE' => 'Fehlerstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_ELV_MISSING' => 'FEHLT',
	'MODULE_PAYMENT_IPAYMENT_ELV_OK' => 'OK',
	'MODULE_PAYMENT_IPAYMENT_ELV_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_ELV_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_ELV_PAYMENT_MODE_DESC' => 'Modus "normal": Weiterleitung zu ipayment, Modus "silent": Erfassung der Daten im Shop',
	'MODULE_PAYMENT_IPAYMENT_ELV_PAYMENT_MODE_TITLE' => 'Zahlungsmodus',
	'MODULE_PAYMENT_IPAYMENT_ELV_SANDBOX_DESC' => 'Sandbox-Modus (Testmodus) aktivieren',
	'MODULE_PAYMENT_IPAYMENT_ELV_SANDBOX_TITLE' => 'Sandbox-Modus',
	'MODULE_PAYMENT_IPAYMENT_ELV_SECURITY_KEY_DESC' => 'Ihr Security-Key',
	'MODULE_PAYMENT_IPAYMENT_ELV_SECURITY_KEY_TITLE' => 'Security-Key',
	'MODULE_PAYMENT_IPAYMENT_ELV_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_IPAYMENT_ELV_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_IPAYMENT_ELV_STATUS_DESC' => 'Möchten Sie Zahlungen via ipayment akzeptieren?',
	'MODULE_PAYMENT_IPAYMENT_ELV_STATUS_TITLE' => 'ipayment-Zahlungsmodul aktivieren',
	'MODULE_PAYMENT_IPAYMENT_ELV_SYSTEM_REQUIREMENTS' => 'Systemanforderungen',
	'MODULE_PAYMENT_IPAYMENT_ELV_TEXT_DESCRIPTION' => '1&1 ipayment für Elektronisches Lastschrift-Verfahren',
	'MODULE_PAYMENT_IPAYMENT_ELV_TEXT_DESCRIPTION_LINK' => '<a target="_new" style="text-decoration: underline;" href="http://www.ipayment.de/">ipayment</a>',
	'MODULE_PAYMENT_IPAYMENT_ELV_TEXT_INFO' => 'Zahlung per ELV (Elektronisches Lastschrift-Verfahren)',
	'MODULE_PAYMENT_IPAYMENT_ELV_TEXT_TITLE' => '1&1 ipayment Lastschrift',
	'MODULE_PAYMENT_IPAYMENT_ELV_TMPORDER_STATUS_ID_DESC' => 'Bestellung während der Eingabe der Zahlungsdaten auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_ELV_TMPORDER_STATUS_ID_TITLE' => 'Temporären Bestellstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_ELV_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_IPAYMENT_ELV_ZONE_TITLE' => 'Zahlungszone'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/ipayment_elv.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ipayment_elv.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_CFG_AUTH' => 'auth',
	'GM_CFG_NORMAL' => 'normal',
	'GM_CFG_PREAUTH' => 'preauth',
	'GM_CFG_SILENT' => 'silent',
	'MODULE_PAYMENT_IPAYMENT_ELV_ACCOUNT_ID_DESC' => 'Deine Merchant ID',
	'MODULE_PAYMENT_IPAYMENT_ELV_ACCOUNT_ID_TITLE' => 'Merchant ID',
	'MODULE_PAYMENT_IPAYMENT_ELV_ADMINACTION_PASSWORD_DESC' => 'Dein Adminaktionspasswort',
	'MODULE_PAYMENT_IPAYMENT_ELV_ADMINACTION_PASSWORD_TITLE' => 'Adminaktionspasswort',
	'MODULE_PAYMENT_IPAYMENT_ELV_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_IPAYMENT_ELV_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_IPAYMENT_ELV_APPLICATION_ID_DESC' => 'Deine Merchant License',
	'MODULE_PAYMENT_IPAYMENT_ELV_APPLICATION_ID_TITLE' => 'Merchant License',
	'MODULE_PAYMENT_IPAYMENT_ELV_APPLICATION_PASSWORD_DESC' => 'Dein Anwendungspasswort',
	'MODULE_PAYMENT_IPAYMENT_ELV_APPLICATION_PASSWORD_TITLE' => 'Anwendungspasswort',
	'MODULE_PAYMENT_IPAYMENT_ELV_AUTH_MODE_DESC' => 'Modus "auth": sofortige Zahlung, Modus "preauth": Verzögerte Zahlungsabwicklung',
	'MODULE_PAYMENT_IPAYMENT_ELV_AUTH_MODE_TITLE' => 'Transaktionsmodus',
	'MODULE_PAYMENT_IPAYMENT_ELV_ERRORORDER_STATUS_ID_DESC' => 'Bestellung im Fehlerfall auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_ELV_ERRORORDER_STATUS_ID_TITLE' => 'Fehlerstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_ELV_MISSING' => 'FEHLT',
	'MODULE_PAYMENT_IPAYMENT_ELV_OK' => 'OK',
	'MODULE_PAYMENT_IPAYMENT_ELV_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_ELV_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_ELV_PAYMENT_MODE_DESC' => 'Modus "normal": Weiterleitung zu ipayment, Modus "silent": Erfassung der Daten im Shop',
	'MODULE_PAYMENT_IPAYMENT_ELV_PAYMENT_MODE_TITLE' => 'Zahlungsmodus',
	'MODULE_PAYMENT_IPAYMENT_ELV_SANDBOX_DESC' => 'Sandbox-Modus (Testmodus) aktivieren',
	'MODULE_PAYMENT_IPAYMENT_ELV_SANDBOX_TITLE' => 'Sandbox-Modus',
	'MODULE_PAYMENT_IPAYMENT_ELV_SECURITY_KEY_DESC' => 'Dein Security-Key',
	'MODULE_PAYMENT_IPAYMENT_ELV_SECURITY_KEY_TITLE' => 'Security-Key',
	'MODULE_PAYMENT_IPAYMENT_ELV_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_IPAYMENT_ELV_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_IPAYMENT_ELV_STATUS_DESC' => 'Möchtest du Zahlungen via ipayment akzeptieren?',
	'MODULE_PAYMENT_IPAYMENT_ELV_STATUS_TITLE' => 'ipayment-Zahlungsmodul aktivieren',
	'MODULE_PAYMENT_IPAYMENT_ELV_SYSTEM_REQUIREMENTS' => 'Systemanforderungen',
	'MODULE_PAYMENT_IPAYMENT_ELV_TEXT_DESCRIPTION' => '1&1 ipayment für Elektronisches Lastschrift-Verfahren',
	'MODULE_PAYMENT_IPAYMENT_ELV_TEXT_DESCRIPTION_LINK' => '<a target="_new" style="text-decoration: underline;" href="http://www.ipayment.de/">ipayment</a>',
	'MODULE_PAYMENT_IPAYMENT_ELV_TEXT_INFO' => 'Zahlung per ELV (Elektronisches Lastschrift-Verfahren)',
	'MODULE_PAYMENT_IPAYMENT_ELV_TEXT_TITLE' => '1&1 ipayment Lastschrift',
	'MODULE_PAYMENT_IPAYMENT_ELV_TMPORDER_STATUS_ID_DESC' => 'Bestellung während der Eingabe der Zahlungsdaten auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_ELV_TMPORDER_STATUS_ID_TITLE' => 'Temporären Bestellstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_ELV_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_IPAYMENT_ELV_ZONE_TITLE' => 'Zahlungszone'
);
